@@ -19,7 +19,7 @@
 
 #include "itemqueryhelper.h"
 
-#include "connection.h"
+#include "commandcontext.h"
 #include "entities.h"
 #include "storage/querybuilder.h"
 #include "libs/imapset_p.h"
@@ -28,6 +28,7 @@
 #include "storage/queryhelper.h"
 #include "collectionqueryhelper.h"
 
+using namespace Akonadi;
 using namespace Akonadi::Server;
 
 void ItemQueryHelper::itemSetToQuery( const ImapSet &set, QueryBuilder &qb, const Collection &collection )
@@ -44,16 +45,22 @@ void ItemQueryHelper::itemSetToQuery( const ImapSet &set, QueryBuilder &qb, cons
   }
 }
 
-void ItemQueryHelper::itemSetToQuery( const ImapSet &set, bool isUid, Connection *connection, QueryBuilder &qb )
+void ItemQueryHelper::itemSetToQuery( const ImapSet &set, bool isUid, CommandContext *context, QueryBuilder &qb )
 {
-  if ( !isUid && connection->selectedCollectionId() >= 0 ) {
-    itemSetToQuery( set, qb, connection->selectedCollection() );
+  if ( !isUid && context->collectionId() >= 0 ) {
+    itemSetToQuery( set, qb, context->collection() );
   } else {
     itemSetToQuery( set, qb );
   }
+
+  if ( context->tagId() >= 0 ) {
+    qb.addJoin( QueryBuilder::InnerJoin, PimItemTagRelation::tableName(),
+                PimItem::idFullColumnName(), PimItemTagRelation::leftFullColumnName() );
+    qb.addValueCondition( PimItemTagRelation::rightFullColumnName(), Query::Equals, context->tagId() );
+  }
 }
 
-void ItemQueryHelper::remoteIdToQuery( const QStringList &rids, Connection *connection, QueryBuilder &qb )
+void ItemQueryHelper::remoteIdToQuery( const QStringList &rids, CommandContext *context, QueryBuilder &qb )
 {
   if ( rids.size() == 1 ) {
     qb.addValueCondition( PimItem::remoteIdFullColumnName(), Query::Equals, rids.first() );
@@ -61,17 +68,22 @@ void ItemQueryHelper::remoteIdToQuery( const QStringList &rids, Connection *conn
     qb.addValueCondition( PimItem::remoteIdFullColumnName(), Query::In, rids );
   }
 
-  if ( connection->resourceContext().isValid() ) {
+  if ( context->resource().isValid() ) {
     qb.addJoin( QueryBuilder::InnerJoin, Collection::tableName(),
                 PimItem::collectionIdFullColumnName(), Collection::idFullColumnName() );
-    qb.addValueCondition( Collection::resourceIdFullColumnName(), Query::Equals, connection->resourceContext().id() );
+    qb.addValueCondition( Collection::resourceIdFullColumnName(), Query::Equals, context->resource().id() );
   }
-  if ( connection->selectedCollectionId() > 0 ) {
-    qb.addValueCondition( PimItem::collectionIdFullColumnName(), Query::Equals, connection->selectedCollectionId() );
+  if ( context->collectionId() > 0 ) {
+    qb.addValueCondition( PimItem::collectionIdFullColumnName(), Query::Equals, context->collectionId() );
+  }
+  if ( context->tagId() > 0 ) {
+    qb.addJoin( QueryBuilder::InnerJoin, PimItemTagRelation::tableName(),
+                PimItem::idFullColumnName(), PimItemTagRelation::leftFullColumnName() );
+    qb.addValueCondition( PimItemTagRelation::rightFullColumnName(), Query::Equals, context->tagId() );
   }
 }
 
-void ItemQueryHelper::gidToQuery( const QStringList &gids, QueryBuilder &qb )
+void ItemQueryHelper::gidToQuery( const QStringList &gids, CommandContext *context, QueryBuilder &qb )
 {
   if ( gids.size() == 1 ) {
     qb.addValueCondition( PimItem::gidFullColumnName(), Query::Equals, gids.first() );
@@ -79,34 +91,39 @@ void ItemQueryHelper::gidToQuery( const QStringList &gids, QueryBuilder &qb )
     qb.addValueCondition( PimItem::gidFullColumnName(), Query::In, gids );
   }
 
+  if ( context->tagId() > 0 ) {
+    qb.addJoin( QueryBuilder::InnerJoin, PimItemTagRelation::tableName(),
+                PimItem::idFullColumnName(), PimItemTagRelation::leftFullColumnName() );
+    qb.addValueCondition( PimItemTagRelation::rightFullColumnName(), Query::Equals, context->tagId() );
+  }
 }
 
-void ItemQueryHelper::scopeToQuery( const Scope &scope, Connection *connection, QueryBuilder &qb )
+void ItemQueryHelper::scopeToQuery( const Scope &scope, CommandContext *context, QueryBuilder &qb )
 {
   if ( scope.scope() == Scope::None || scope.scope() == Scope::Uid ) {
-    itemSetToQuery( scope.uidSet(), scope.scope() == Scope::Uid, connection, qb );
+    itemSetToQuery( scope.uidSet(), scope.scope() == Scope::Uid, context, qb );
     return;
   }
 
   if ( scope.scope() == Scope::Gid ) {
-    ItemQueryHelper::gidToQuery( scope.gidSet(), qb );
+    ItemQueryHelper::gidToQuery( scope.gidSet(), context, qb );
     return;
   }
 
-  if ( connection->selectedCollectionId() <= 0 && !connection->resourceContext().isValid() ) {
+  if ( context->collectionId() <= 0 && !context->resource().isValid() ) {
       throw HandlerException( "Operations based on remote identifiers require a resource or collection context" );
   }
 
   if ( scope.scope() == Scope::Rid ) {
-    ItemQueryHelper::remoteIdToQuery( scope.ridSet(), connection, qb );
+    ItemQueryHelper::remoteIdToQuery( scope.ridSet(), context, qb );
     return;
   } else if ( scope.scope() == Scope::HierarchicalRid ) {
     QStringList ridChain = scope.ridChain();
     const QString itemRid = ridChain.takeFirst();
-    const Collection parentCol = CollectionQueryHelper::resolveHierarchicalRID( ridChain, connection->resourceContext().id() );
-    const Collection::Id oldSelection = connection->selectedCollectionId();
-    remoteIdToQuery( QStringList() << itemRid, connection, qb );
-    connection->setSelectedCollection( oldSelection );
+    const Collection parentCol = CollectionQueryHelper::resolveHierarchicalRID( ridChain, context->resource().id() );
+    const Collection oldSelection = context->collection();
+    remoteIdToQuery( QStringList() << itemRid, context, qb );
+    context->setCollection( oldSelection );
     return;
   }
 
